@@ -572,7 +572,7 @@ gil_unselect_all (GnomeIconList *gil, GdkEvent *event, gpointer keep)
 void
 gnome_icon_list_select_all (GnomeIconList *gil)
 {
-	uint i;
+	guint i;
 	
 	g_return_if_fail (gil != NULL);
 	g_return_if_fail (IS_GIL (gil));
@@ -900,7 +900,7 @@ icon_event (GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 
 	if (priv->editing_icon && event->type == GDK_BUTTON_PRESS) {
 		gnome_icon_text_item_stop_editing (priv->editing_icon->text, FALSE);
-		priv->editing_icon = FALSE;
+		priv->editing_icon = NULL;
 	}
 
 	switch (priv->selection_mode) {
@@ -3165,7 +3165,9 @@ gnome_icon_list_get_icon_text_item (GnomeIconList *gil,
 
 	g_return_val_if_fail (gil != NULL, NULL);
 	g_return_val_if_fail (IS_GIL (gil), NULL);
-	g_return_val_if_fail (idx >= 0 && idx < gil->_priv->icons, NULL);
+
+	if  (idx < 0 || idx >= gil->_priv->icons)
+		return  NULL;
 
 	icon = g_array_index (gil->_priv->icon_list, Icon*, idx);
 
@@ -3180,7 +3182,9 @@ gnome_icon_list_get_icon_pixbuf_item (GnomeIconList *gil,
 
 	g_return_val_if_fail (gil != NULL, NULL);
 	g_return_val_if_fail (IS_GIL (gil), NULL);
-	g_return_val_if_fail (idx >= 0 && idx < gil->_priv->icons, NULL);
+
+	if  (idx < 0 || idx >= gil->_priv->icons)
+		return  NULL;
 
 	icon = g_array_index (gil->_priv->icon_list, Icon*, idx);
 
