@@ -48,6 +48,8 @@ GdkPixbuf * _gnome_thumbnail_load_scaled_jpeg (const char *uri,
  * large amounts.
  *
  * Return value: a scaled pixbuf
+ * 
+ * Since: 2.2
  **/
 GdkPixbuf *
 gnome_thumbnail_scale_down_pixbuf (GdkPixbuf *pixbuf,
@@ -276,7 +278,7 @@ term_source (j_decompress_ptr cinfo)
 static void
 vfs_src (j_decompress_ptr cinfo, Source *src, GnomeVFSHandle *handle)
 {
-	cinfo->src = src;
+	cinfo->src = (struct jpeg_source_mgr *)src;
 	src->pub.init_source = init_source;
 	src->pub.fill_input_buffer = fill_input_buffer;
 	src->pub.skip_input_data = skip_input_data;
